==> bootstrap-styled-2.3.1.tgz: package/README.md <==
# bootstrap-styled

[![Build Status](https://travis-ci.org/bootstrap-styled/bootstrap-styled.svg?branch=master)](https://travis-ci.org/bootstrap-styled/bootstrap-styled)
[![npm Version](https://img.shields.io/npm/v/bootstrap-styled.svg?style=flat)](https://www.npmjs.com/package/bootstrap-styled) 
[![License](https://img.shields.io/npm/l/bootstrap-styled.svg?style=flat)](https://www.npmjs.com/package/bootstrap-styled) 
[![NPM monthly downloads](https://img.shields.io/npm/dm/bootstrap-styled.svg?style=flat)](https://npmjs.org/package/bootstrap-styled) 
[![NPM total downloads](https://img.shields.io/npm/dt/bootstrap-styled.svg?style=flat)](https://npmjs.org/package/bootstrap-styled) 
[![npm Version](https://img.shields.io/node/v/bootstrap-styled.svg?style=flat)](https://www.npmjs.com/package/bootstrap-styled) 
[![Module formats](https://img.shields.io/badge/module%20formats-umd%2C%20cjs%2C%20esm-green.svg?style=flat)](https://www.npmjs.com/package/bootstrap-styled)
[![Coverage](https://sonarcloud.io/api/project_badges/measure?project=com.github.bootstrap-styled.bootstrap-styled&metric=coverage)](https://sonarcloud.io/dashboard?id=com.github.bootstrap-styled.bootstrap-styled) [![Quality gate status](https://sonarcloud.io/api/project_badges/measure?project=com.github.bootstrap-styled.bootstrap-styled&metric=alert_status)](https://sonarcloud.io/dashboard?id=com.github.bootstrap-styled.bootstrap-styled)
[![gitter](https://badges.gitter.im/bootstrap-styled/bootstrap-styled.svg)](https://gitter.im/bootstrap-styled) [![Greenkeeper badge](https://badges.greenkeeper.io/bootstrap-styled/bootstrap-styled.svg)](https://greenkeeper.io/)

List of bootstrap variables and theme auto-configuration functions.

## Table of Contents

  - [Documentation](#documentation)
  - [Contributing](#contributing)
  - [License MIT](#license-mit)

---

## Documentation

Read [bootstrap-styled documentation](https://bootstrap-styled.github.io/bootstrap-styled).


## Contributing

If you want to contribute to bootstrap-styled please see our [contributing and community guidelines](https://github.com/bootstrap-styled/bootstrap-styled/blob/master/CONTRIBUTING.md), they\'ll help you get set up locally and explain the whole process.

Please also note that all repositories under the bootstrap-styled organization follow our [Code of Conduct](https://github.com/bootstrap-styled/bootstrap-styled/blob/master/CODE_OF_CONDUCT.md), make sure to review and follow it.

## License MIT

The MIT License

Copyright (c) 2017-2018 Yeutech Company Limited. https://bootstrap-styled.github.io/bootstrap-styled

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.

==> bootstrap-styled-2.4.0.tgz: package/README.md <==
# bootstrap-styled

[![Build Status](https://travis-ci.org/bootstrap-styled/bootstrap-styled.svg?branch=master)](https://travis-ci.org/bootstrap-styled/bootstrap-styled)
[![npm Version](https://img.shields.io/npm/v/bootstrap-styled.svg?style=flat)](https://www.npmjs.com/package/bootstrap-styled) 
[![License](https://img.shields.io/npm/l/bootstrap-styled.svg?style=flat)](https://www.npmjs.com/package/bootstrap-styled) 
[![NPM monthly downloads](https://img.shields.io/npm/dm/bootstrap-styled.svg?style=flat)](https://npmjs.org/package/bootstrap-styled) 
[![NPM total downloads](https://img.shields.io/npm/dt/bootstrap-styled.svg?style=flat)](https://npmjs.org/package/bootstrap-styled) 
[![npm Version](https://img.shields.io/node/v/bootstrap-styled.svg?style=flat)](https://www.npmjs.com/package/bootstrap-styled) 
[![Module formats](https://img.shields.io/badge/module%20formats-umd%2C%20cjs%2C%20esm-green.svg?style=flat)](https://www.npmjs.com/package/bootstrap-styled)
[![Coverage](https://sonarcloud.io/api/project_badges/measure?project=com.github.bootstrap-styled.bootstrap-styled&metric=coverage)](https://sonarcloud.io/dashboard?id=com.github.bootstrap-styled.bootstrap-styled) [![Quality gate status](https://sonarcloud.io/api/project_badges/measure?project=com.github.bootstrap-styled.bootstrap-styled&metric=alert_status)](https://sonarcloud.io/dashboard?id=com.github.bootstrap-styled.bootstrap-styled)
[![gitter](https://badges.gitter.im/bootstrap-styled/bootstrap-styled.svg)](https://gitter.im/bootstrap-styled) [![Greenkeeper badge](https://badges.greenkeeper.io/bootstrap-styled/bootstrap-styled.svg)](https://greenkeeper.io/)

List of bootstrap variables and theme auto-configuration functions.

## Table of Contents

  - [Documentation](#documentation)
  - [Contributing](#contributing)
  - [License MIT](#license-mit)

---

## Documentation

Read [bootstrap-styled documentation](https://bootstrap-styled.github.io/bootstrap-styled).


## Contributing

If you want to contribute to bootstrap-styled please see our [contributing and community guidelines](https://github.com/bootstrap-styled/bootstrap-styled/blob/master/.github/CONTRIBUTING.md), they\'ll help you get set up locally and explain the whole process.

Please also note that all repositories under the bootstrap-styled organization follow our [Code of Conduct](https://github.com/bootstrap-styled/bootstrap-styled/blob/master/CODE_OF_CONDUCT.md), make sure to review and follow it.

## License MIT

The MIT License

Copyright (c) 2017-2018 Yeutech Company Limited. https://bootstrap-styled.github.io/bootstrap-styled

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.
